# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import is_given, path_template, maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ..._base_client import make_request_options
from ...types.magic_transit import cf_interconnect_update_params, cf_interconnect_bulk_update_params
from ...types.magic_transit.health_check_param import HealthCheckParam
from ...types.magic_transit.cf_interconnect_get_response import CfInterconnectGetResponse
from ...types.magic_transit.cf_interconnect_list_response import CfInterconnectListResponse
from ...types.magic_transit.cf_interconnect_update_response import CfInterconnectUpdateResponse
from ...types.magic_transit.cf_interconnect_bulk_update_response import CfInterconnectBulkUpdateResponse

__all__ = ["CfInterconnectsResource", "AsyncCfInterconnectsResource"]


class CfInterconnectsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CfInterconnectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return CfInterconnectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CfInterconnectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return CfInterconnectsResourceWithStreamingResponse(self)

    def update(
        self,
        cf_interconnect_id: str,
        *,
        account_id: str,
        automatic_return_routing: bool | Omit = omit,
        description: str | Omit = omit,
        gre: cf_interconnect_update_params.GRE | Omit = omit,
        health_check: HealthCheckParam | Omit = omit,
        interface_address: str | Omit = omit,
        interface_address6: str | Omit = omit,
        mtu: int | Omit = omit,
        name: str | Omit = omit,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectUpdateResponse:
        """Updates a specific interconnect associated with an account.

        Use
        `?validate_only=true` as an optional query parameter to only run validation
        without persisting changes.

        Args:
          account_id: Identifier

          cf_interconnect_id: Identifier

          automatic_return_routing: True if automatic stateful return routing should be enabled for a tunnel, false
              otherwise. Requires the `coupler_integration` account flag to be enabled;
              requests setting this to `true` without that flag will be rejected.

          description: An optional description of the interconnect.

          gre: The configuration specific to GRE interconnects.

          interface_address: A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for each side
              of the tunnel. Select the subnet from the following private IP space:
              10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.

          interface_address6: A 127 bit IPV6 prefix from within the virtual_subnet6 prefix space with the
              address being the first IP of the subnet and not same as the address of
              virtual_subnet6. Eg if virtual_subnet6 is 2606:54c1:7:0:a9fe:12d2::/127 ,
              interface_address6 could be 2606:54c1:7:0:a9fe:12d2:1:200/127

          mtu: The Maximum Transmission Unit (MTU) in bytes for the interconnect. The minimum
              value is 576.

          name: The name of the interconnect. The name cannot share a name with other tunnels.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not cf_interconnect_id:
            raise ValueError(f"Expected a non-empty value for `cf_interconnect_id` but received {cf_interconnect_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return self._put(
            path_template(
                "/accounts/{account_id}/magic/cf_interconnects/{cf_interconnect_id}",
                account_id=account_id,
                cf_interconnect_id=cf_interconnect_id,
            ),
            body=maybe_transform(
                {
                    "automatic_return_routing": automatic_return_routing,
                    "description": description,
                    "gre": gre,
                    "health_check": health_check,
                    "interface_address": interface_address,
                    "interface_address6": interface_address6,
                    "mtu": mtu,
                    "name": name,
                },
                cf_interconnect_update_params.CfInterconnectUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectUpdateResponse], ResultWrapper[CfInterconnectUpdateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectListResponse:
        """
        Lists interconnects associated with an account.

        Args:
          account_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return self._get(
            path_template("/accounts/{account_id}/magic/cf_interconnects", account_id=account_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectListResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectListResponse], ResultWrapper[CfInterconnectListResponse]),
        )

    def bulk_update(
        self,
        *,
        account_id: str,
        body: object,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectBulkUpdateResponse:
        """Updates multiple interconnects associated with an account.

        Use
        `?validate_only=true` as an optional query parameter to only run validation
        without persisting changes.

        Args:
          account_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return self._put(
            path_template("/accounts/{account_id}/magic/cf_interconnects", account_id=account_id),
            body=maybe_transform(body, cf_interconnect_bulk_update_params.CfInterconnectBulkUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectBulkUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectBulkUpdateResponse], ResultWrapper[CfInterconnectBulkUpdateResponse]),
        )

    def get(
        self,
        cf_interconnect_id: str,
        *,
        account_id: str,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectGetResponse:
        """
        Lists details for a specific interconnect.

        Args:
          account_id: Identifier

          cf_interconnect_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not cf_interconnect_id:
            raise ValueError(f"Expected a non-empty value for `cf_interconnect_id` but received {cf_interconnect_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return self._get(
            path_template(
                "/accounts/{account_id}/magic/cf_interconnects/{cf_interconnect_id}",
                account_id=account_id,
                cf_interconnect_id=cf_interconnect_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectGetResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectGetResponse], ResultWrapper[CfInterconnectGetResponse]),
        )


class AsyncCfInterconnectsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCfInterconnectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCfInterconnectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCfInterconnectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncCfInterconnectsResourceWithStreamingResponse(self)

    async def update(
        self,
        cf_interconnect_id: str,
        *,
        account_id: str,
        automatic_return_routing: bool | Omit = omit,
        description: str | Omit = omit,
        gre: cf_interconnect_update_params.GRE | Omit = omit,
        health_check: HealthCheckParam | Omit = omit,
        interface_address: str | Omit = omit,
        interface_address6: str | Omit = omit,
        mtu: int | Omit = omit,
        name: str | Omit = omit,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectUpdateResponse:
        """Updates a specific interconnect associated with an account.

        Use
        `?validate_only=true` as an optional query parameter to only run validation
        without persisting changes.

        Args:
          account_id: Identifier

          cf_interconnect_id: Identifier

          automatic_return_routing: True if automatic stateful return routing should be enabled for a tunnel, false
              otherwise. Requires the `coupler_integration` account flag to be enabled;
              requests setting this to `true` without that flag will be rejected.

          description: An optional description of the interconnect.

          gre: The configuration specific to GRE interconnects.

          interface_address: A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for each side
              of the tunnel. Select the subnet from the following private IP space:
              10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.

          interface_address6: A 127 bit IPV6 prefix from within the virtual_subnet6 prefix space with the
              address being the first IP of the subnet and not same as the address of
              virtual_subnet6. Eg if virtual_subnet6 is 2606:54c1:7:0:a9fe:12d2::/127 ,
              interface_address6 could be 2606:54c1:7:0:a9fe:12d2:1:200/127

          mtu: The Maximum Transmission Unit (MTU) in bytes for the interconnect. The minimum
              value is 576.

          name: The name of the interconnect. The name cannot share a name with other tunnels.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not cf_interconnect_id:
            raise ValueError(f"Expected a non-empty value for `cf_interconnect_id` but received {cf_interconnect_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return await self._put(
            path_template(
                "/accounts/{account_id}/magic/cf_interconnects/{cf_interconnect_id}",
                account_id=account_id,
                cf_interconnect_id=cf_interconnect_id,
            ),
            body=await async_maybe_transform(
                {
                    "automatic_return_routing": automatic_return_routing,
                    "description": description,
                    "gre": gre,
                    "health_check": health_check,
                    "interface_address": interface_address,
                    "interface_address6": interface_address6,
                    "mtu": mtu,
                    "name": name,
                },
                cf_interconnect_update_params.CfInterconnectUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectUpdateResponse], ResultWrapper[CfInterconnectUpdateResponse]),
        )

    async def list(
        self,
        *,
        account_id: str,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectListResponse:
        """
        Lists interconnects associated with an account.

        Args:
          account_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return await self._get(
            path_template("/accounts/{account_id}/magic/cf_interconnects", account_id=account_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectListResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectListResponse], ResultWrapper[CfInterconnectListResponse]),
        )

    async def bulk_update(
        self,
        *,
        account_id: str,
        body: object,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectBulkUpdateResponse:
        """Updates multiple interconnects associated with an account.

        Use
        `?validate_only=true` as an optional query parameter to only run validation
        without persisting changes.

        Args:
          account_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return await self._put(
            path_template("/accounts/{account_id}/magic/cf_interconnects", account_id=account_id),
            body=await async_maybe_transform(body, cf_interconnect_bulk_update_params.CfInterconnectBulkUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectBulkUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectBulkUpdateResponse], ResultWrapper[CfInterconnectBulkUpdateResponse]),
        )

    async def get(
        self,
        cf_interconnect_id: str,
        *,
        account_id: str,
        x_magic_new_hc_target: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CfInterconnectGetResponse:
        """
        Lists details for a specific interconnect.

        Args:
          account_id: Identifier

          cf_interconnect_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not cf_interconnect_id:
            raise ValueError(f"Expected a non-empty value for `cf_interconnect_id` but received {cf_interconnect_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "x-magic-new-hc-target": ("true" if x_magic_new_hc_target else "false")
                    if is_given(x_magic_new_hc_target)
                    else not_given
                }
            ),
            **(extra_headers or {}),
        }
        return await self._get(
            path_template(
                "/accounts/{account_id}/magic/cf_interconnects/{cf_interconnect_id}",
                account_id=account_id,
                cf_interconnect_id=cf_interconnect_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[CfInterconnectGetResponse]._unwrapper,
            ),
            cast_to=cast(Type[CfInterconnectGetResponse], ResultWrapper[CfInterconnectGetResponse]),
        )


class CfInterconnectsResourceWithRawResponse:
    def __init__(self, cf_interconnects: CfInterconnectsResource) -> None:
        self._cf_interconnects = cf_interconnects

        self.update = to_raw_response_wrapper(
            cf_interconnects.update,
        )
        self.list = to_raw_response_wrapper(
            cf_interconnects.list,
        )
        self.bulk_update = to_raw_response_wrapper(
            cf_interconnects.bulk_update,
        )
        self.get = to_raw_response_wrapper(
            cf_interconnects.get,
        )


class AsyncCfInterconnectsResourceWithRawResponse:
    def __init__(self, cf_interconnects: AsyncCfInterconnectsResource) -> None:
        self._cf_interconnects = cf_interconnects

        self.update = async_to_raw_response_wrapper(
            cf_interconnects.update,
        )
        self.list = async_to_raw_response_wrapper(
            cf_interconnects.list,
        )
        self.bulk_update = async_to_raw_response_wrapper(
            cf_interconnects.bulk_update,
        )
        self.get = async_to_raw_response_wrapper(
            cf_interconnects.get,
        )


class CfInterconnectsResourceWithStreamingResponse:
    def __init__(self, cf_interconnects: CfInterconnectsResource) -> None:
        self._cf_interconnects = cf_interconnects

        self.update = to_streamed_response_wrapper(
            cf_interconnects.update,
        )
        self.list = to_streamed_response_wrapper(
            cf_interconnects.list,
        )
        self.bulk_update = to_streamed_response_wrapper(
            cf_interconnects.bulk_update,
        )
        self.get = to_streamed_response_wrapper(
            cf_interconnects.get,
        )


class AsyncCfInterconnectsResourceWithStreamingResponse:
    def __init__(self, cf_interconnects: AsyncCfInterconnectsResource) -> None:
        self._cf_interconnects = cf_interconnects

        self.update = async_to_streamed_response_wrapper(
            cf_interconnects.update,
        )
        self.list = async_to_streamed_response_wrapper(
            cf_interconnects.list,
        )
        self.bulk_update = async_to_streamed_response_wrapper(
            cf_interconnects.bulk_update,
        )
        self.get = async_to_streamed_response_wrapper(
            cf_interconnects.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel
from .rate_plan import RatePlan

__all__ = ["Subscription"]


class Subscription(BaseModel):
    id: Optional[str] = None
    """Subscription identifier tag."""

    currency: Optional[str] = None
    """The monetary unit in which pricing information is displayed."""

    current_period_end: Optional[datetime] = None
    """The end of the current period and also when the next billing is due."""

    current_period_start: Optional[datetime] = None
    """When the current billing period started.

    May match initial_period_start if this is the first period.
    """

    frequency: Optional[Literal["weekly", "monthly", "quarterly", "yearly"]] = None
    """How often the subscription is renewed automatically."""

    price: Optional[float] = None
    """The price of the subscription that will be billed, in US dollars."""

    rate_plan: Optional[RatePlan] = None
    """The rate plan applied to the subscription."""

    state: Optional[Literal["Trial", "Provisioned", "Paid", "AwaitingPayment", "Cancelled", "Failed", "Expired"]] = None
    """The state that the subscription is in."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["AudioTrackEditParams"]


class AudioTrackEditParams(TypedDict, total=False):
    account_id: Required[str]
    """The account identifier tag."""

    identifier: Required[str]
    """A Cloudflare-generated unique identifier for a media item."""

    default: bool
    """Denotes whether the audio track will be played by default in a player."""

    label: str
    """
    A string to uniquely identify the track amongst other audio track labels for the
    specified video.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .snapshots import (
    SnapshotsResource,
    AsyncSnapshotsResource,
    SnapshotsResourceWithRawResponse,
    AsyncSnapshotsResourceWithRawResponse,
    SnapshotsResourceWithStreamingResponse,
    AsyncSnapshotsResourceWithStreamingResponse,
)
from .permissions import (
    PermissionsResource,
    AsyncPermissionsResource,
    PermissionsResourceWithRawResponse,
    AsyncPermissionsResourceWithRawResponse,
    PermissionsResourceWithStreamingResponse,
    AsyncPermissionsResourceWithStreamingResponse,
)
from .indicator_feeds import (
    IndicatorFeedsResource,
    AsyncIndicatorFeedsResource,
    IndicatorFeedsResourceWithRawResponse,
    AsyncIndicatorFeedsResourceWithRawResponse,
    IndicatorFeedsResourceWithStreamingResponse,
    AsyncIndicatorFeedsResourceWithStreamingResponse,
)

__all__ = [
    "SnapshotsResource",
    "AsyncSnapshotsResource",
    "SnapshotsResourceWithRawResponse",
    "AsyncSnapshotsResourceWithRawResponse",
    "SnapshotsResourceWithStreamingResponse",
    "AsyncSnapshotsResourceWithStreamingResponse",
    "PermissionsResource",
    "AsyncPermissionsResource",
    "PermissionsResourceWithRawResponse",
    "AsyncPermissionsResourceWithRawResponse",
    "PermissionsResourceWithStreamingResponse",
    "AsyncPermissionsResourceWithStreamingResponse",
    "IndicatorFeedsResource",
    "AsyncIndicatorFeedsResource",
    "IndicatorFeedsResourceWithRawResponse",
    "AsyncIndicatorFeedsResourceWithRawResponse",
    "IndicatorFeedsResourceWithStreamingResponse",
    "AsyncIndicatorFeedsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["ResponseInfo", "Source"]


class Source(BaseModel):
    pointer: Optional[str] = None


class ResponseInfo(BaseModel):
    code: int

    message: str

    documentation_url: Optional[str] = None

    source: Optional[Source] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["StreamListParams"]


class StreamListParams(TypedDict, total=False):
    account_id: Required[str]
    """The account identifier tag."""

    id: str
    """Filter by video ID(s). Can be a single ID or a comma-separated list of IDs."""

    after: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Alias for 'start'.

    Returns videos created after this date/time (RFC 3339 format).
    """

    asc: bool
    """Lists videos in ascending order of creation."""

    before: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Alias for 'end'.

    Returns videos created before this date/time (RFC 3339 format).
    """

    creator: str
    """A user-defined identifier for the media creator."""

    end: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Lists videos created before the specified date."""

    include_counts: bool
    """
    Includes the total number of videos associated with the submitted query
    parameters.
    """

    limit: int
    """Maximum number of videos to return (default 1000, max 1000)."""

    live_input_id: str
    """Filter by live input ID to find videos associated with a specific live stream."""

    name: str
    """Filter by video name/UID(s). Can be a single name or a comma-separated list."""

    search: str
    """Provides a partial word match of the `name` key in the `meta` field.

    Slow for medium to large video libraries. May be unavailable for very large
    libraries.
    """

    start: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Lists videos created after the specified date."""

    status: Literal["pendingupload", "downloading", "queued", "inprogress", "ready", "error", "live-inprogress"]
    """Specifies the processing status for all quality levels for a video."""

    type: str
    """Specifies whether the video is `vod` or `live`."""

    video_name: str
    """Provides a fast, exact string match on the `name` key in the `meta` field."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "ScanGetResponse",
    "Data",
    "DataConsole",
    "DataConsoleMessage",
    "DataCookie",
    "DataGlobal",
    "DataLink",
    "DataPerformance",
    "DataRequest",
    "DataRequestRequest",
    "DataRequestRequestInitiator",
    "DataRequestRequestRequest",
    "DataRequestRequestRedirectResponse",
    "DataRequestRequestRedirectResponseSecurityHeader",
    "DataRequestResponse",
    "DataRequestResponseASN",
    "DataRequestResponseGeoip",
    "DataRequestResponseResponse",
    "DataRequestResponseResponseSecurityDetails",
    "DataRequestResponseResponseSecurityHeader",
    "Lists",
    "ListsCertificate",
    "Meta",
    "MetaProcessors",
    "MetaProcessorsASN",
    "MetaProcessorsASNData",
    "MetaProcessorsDNS",
    "MetaProcessorsDNSData",
    "MetaProcessorsDomainCategories",
    "MetaProcessorsDomainCategoriesData",
    "MetaProcessorsGeoip",
    "MetaProcessorsGeoipData",
    "MetaProcessorsGeoipDataGeoip",
    "MetaProcessorsPhishing",
    "MetaProcessorsRadarRank",
    "MetaProcessorsRadarRankData",
    "MetaProcessorsWappa",
    "MetaProcessorsWappaData",
    "MetaProcessorsWappaDataCategory",
    "MetaProcessorsWappaDataConfidence",
    "MetaProcessorsAgentReadiness",
    "MetaProcessorsAgentReadinessChecks",
    "MetaProcessorsAgentReadinessChecksBotAccessControl",
    "MetaProcessorsAgentReadinessChecksBotAccessControlContentSignals",
    "MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidence",
    "MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTXTAIRules",
    "MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidence",
    "MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuth",
    "MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidence",
    "MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksCommerce",
    "MetaProcessorsAgentReadinessChecksCommerceAcp",
    "MetaProcessorsAgentReadinessChecksCommerceAcpEvidence",
    "MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksCommerceAp2",
    "MetaProcessorsAgentReadinessChecksCommerceAp2Evidence",
    "MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceFinding",
    "MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceRequest",
    "MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceResponse",
    "MetaProcessorsAgentReadinessChecksCommerceUcp",
    "MetaProcessorsAgentReadinessChecksCommerceUcpEvidence",
    "MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksCommerceX402",
    "MetaProcessorsAgentReadinessChecksCommerceX402Evidence",
    "MetaProcessorsAgentReadinessChecksCommerceX402EvidenceFinding",
    "MetaProcessorsAgentReadinessChecksCommerceX402EvidenceRequest",
    "MetaProcessorsAgentReadinessChecksCommerceX402EvidenceResponse",
    "MetaProcessorsAgentReadinessChecksContentAccessibility",
    "MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiation",
    "MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidence",
    "MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoverability",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeaders",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXT",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoverabilitySitemap",
    "MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscovery",
    "MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCard",
    "MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoveryAgentSkills",
    "MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoveryAPICatalog",
    "MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCard",
    "MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscovery",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResource",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceResponse",
    "MetaProcessorsAgentReadinessChecksDiscoveryWebMcp",
    "MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidence",
    "MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceFinding",
    "MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceRequest",
    "MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceResponse",
    "MetaProcessorsAgentReadinessNextLevel",
    "MetaProcessorsAgentReadinessNextLevelRequirement",
    "MetaProcessorsPhishingV2",
    "MetaProcessorsRobotsTXT",
    "MetaProcessorsRobotsTXTData",
    "MetaProcessorsRobotsTXTDataRules",
    "MetaProcessorsRobotsTXTDataRulesapi_empty",
    "MetaProcessorsRobotsTXTDataRulesapi_emptyContentSignal",
    "MetaProcessorsURLCategories",
    "MetaProcessorsURLCategoriesData",
    "MetaProcessorsURLCategoriesDataContent",
    "MetaProcessorsURLCategoriesDataInherited",
    "MetaProcessorsURLCategoriesDataInheritedContent",
    "MetaProcessorsURLCategoriesDataInheritedRisk",
    "MetaProcessorsURLCategoriesDataRisk",
    "Page",
    "PageScreenshot",
    "Scanner",
    "Stats",
    "StatsDomainStat",
    "StatsIPStat",
    "StatsIPStatASN",
    "StatsIPStatGeoip",
    "StatsProtocolStat",
    "StatsResourceStat",
    "StatsServerStat",
    "StatsTLSStat",
    "StatsTLSStatProtocols",
    "Task",
    "TaskOptions",
    "Verdicts",
    "VerdictsOverall",
]


class DataConsoleMessage(BaseModel):
    level: str

    source: str

    text: str

    url: str


class DataConsole(BaseModel):
    message: DataConsoleMessage


class DataCookie(BaseModel):
    domain: str

    expires: float

    http_only: bool = FieldInfo(alias="httpOnly")

    name: str

    path: str

    priority: str

    same_party: bool = FieldInfo(alias="sameParty")

    secure: bool

    session: bool

    size: float

    source_port: float = FieldInfo(alias="sourcePort")

    source_scheme: str = FieldInfo(alias="sourceScheme")

    value: str


class DataGlobal(BaseModel):
    prop: str

    type: str


class DataLink(BaseModel):
    href: str

    text: str


class DataPerformance(BaseModel):
    duration: float

    entry_type: str = FieldInfo(alias="entryType")

    name: str

    start_time: float = FieldInfo(alias="startTime")


class DataRequestRequestInitiator(BaseModel):
    host: str

    type: str

    url: str


class DataRequestRequestRequest(BaseModel):
    initial_priority: str = FieldInfo(alias="initialPriority")

    is_same_site: bool = FieldInfo(alias="isSameSite")

    method: str

    mixed_content_type: str = FieldInfo(alias="mixedContentType")

    referrer_policy: str = FieldInfo(alias="referrerPolicy")

    url: str

    headers: Optional[object] = None


class DataRequestRequestRedirectResponseSecurityHeader(BaseModel):
    name: str

    value: str


class DataRequestRequestRedirectResponse(BaseModel):
    charset: str

    mime_type: str = FieldInfo(alias="mimeType")

    protocol: str

    remote_ip_address: str = FieldInfo(alias="remoteIPAddress")

    remote_port: float = FieldInfo(alias="remotePort")

    security_headers: List[DataRequestRequestRedirectResponseSecurityHeader] = FieldInfo(alias="securityHeaders")

    security_state: str = FieldInfo(alias="securityState")

    status: float

    status_text: str = FieldInfo(alias="statusText")

    url: str

    headers: Optional[object] = None


class DataRequestRequest(BaseModel):
    document_url: str = FieldInfo(alias="documentURL")

    has_user_gesture: bool = FieldInfo(alias="hasUserGesture")

    initiator: DataRequestRequestInitiator

    redirect_has_extra_info: bool = FieldInfo(alias="redirectHasExtraInfo")

    request: DataRequestRequestRequest

    request_id: str = FieldInfo(alias="requestId")

    type: str

    wall_time: float = FieldInfo(alias="wallTime")

    frame_id: Optional[str] = FieldInfo(alias="frameId", default=None)

    loader_id: Optional[str] = FieldInfo(alias="loaderId", default=None)

    primary_request: Optional[bool] = FieldInfo(alias="primaryRequest", default=None)

    redirect_response: Optional[DataRequestRequestRedirectResponse] = FieldInfo(alias="redirectResponse", default=None)


class DataRequestResponseASN(BaseModel):
    asn: str

    country: str

    description: str

    ip: str

    name: str

    org: str


class DataRequestResponseGeoip(BaseModel):
    city: str

    country: str

    country_name: str

    geoname_id: str = FieldInfo(alias="geonameId")

    ll: List[float]

    region: str


class DataRequestResponseResponseSecurityDetails(BaseModel):
    certificate_id: float = FieldInfo(alias="certificateId")

    certificate_transparency_compliance: str = FieldInfo(alias="certificateTransparencyCompliance")

    cipher: str

    encrypted_client_hello: bool = FieldInfo(alias="encryptedClientHello")

    issuer: str

    key_exchange: str = FieldInfo(alias="keyExchange")

    key_exchange_group: str = FieldInfo(alias="keyExchangeGroup")

    protocol: str

    san_list: List[str] = FieldInfo(alias="sanList")

    server_signature_algorithm: float = FieldInfo(alias="serverSignatureAlgorithm")

    subject_name: str = FieldInfo(alias="subjectName")

    valid_from: float = FieldInfo(alias="validFrom")

    valid_to: float = FieldInfo(alias="validTo")


class DataRequestResponseResponseSecurityHeader(BaseModel):
    name: str

    value: str


class DataRequestResponseResponse(BaseModel):
    charset: str

    mime_type: str = FieldInfo(alias="mimeType")

    protocol: str

    remote_ip_address: str = FieldInfo(alias="remoteIPAddress")

    remote_port: float = FieldInfo(alias="remotePort")

    security_details: DataRequestResponseResponseSecurityDetails = FieldInfo(alias="securityDetails")

    security_headers: List[DataRequestResponseResponseSecurityHeader] = FieldInfo(alias="securityHeaders")

    security_state: str = FieldInfo(alias="securityState")

    status: float

    status_text: str = FieldInfo(alias="statusText")

    url: str

    headers: Optional[object] = None


class DataRequestResponse(BaseModel):
    asn: DataRequestResponseASN

    data_length: float = FieldInfo(alias="dataLength")

    encoded_data_length: float = FieldInfo(alias="encodedDataLength")

    geoip: DataRequestResponseGeoip

    has_extra_info: bool = FieldInfo(alias="hasExtraInfo")

    request_id: str = FieldInfo(alias="requestId")

    response: DataRequestResponseResponse

    size: float

    type: str

    content_available: Optional[bool] = FieldInfo(alias="contentAvailable", default=None)

    hash: Optional[str] = None


class DataRequest(BaseModel):
    request: DataRequestRequest

    response: DataRequestResponse

    requests: Optional[List[DataRequestRequest]] = None


class Data(BaseModel):
    console: List[DataConsole]

    cookies: List[DataCookie]

    globals: List[DataGlobal]

    links: List[DataLink]

    performance: List[DataPerformance]

    requests: List[DataRequest]


class ListsCertificate(BaseModel):
    issuer: str

    subject_name: str = FieldInfo(alias="subjectName")

    valid_from: float = FieldInfo(alias="validFrom")

    valid_to: float = FieldInfo(alias="validTo")


class Lists(BaseModel):
    asns: List[str]

    certificates: List[ListsCertificate]

    continents: List[str]

    countries: List[str]

    domains: List[str]

    hashes: List[str]

    ips: List[str]

    link_domains: List[str] = FieldInfo(alias="linkDomains")

    servers: List[str]

    urls: List[str]


class MetaProcessorsASNData(BaseModel):
    asn: str

    country: str

    description: str

    ip: str

    name: str


class MetaProcessorsASN(BaseModel):
    data: List[MetaProcessorsASNData]


class MetaProcessorsDNSData(BaseModel):
    address: str

    dnssec_valid: bool

    name: str

    type: str


class MetaProcessorsDNS(BaseModel):
    data: List[MetaProcessorsDNSData]


class MetaProcessorsDomainCategoriesData(BaseModel):
    inherited: object

    is_primary: bool = FieldInfo(alias="isPrimary")

    name: str


class MetaProcessorsDomainCategories(BaseModel):
    data: List[MetaProcessorsDomainCategoriesData]


class MetaProcessorsGeoipDataGeoip(BaseModel):
    city: str

    country: str

    country_name: str

    ll: List[float]

    region: str


class MetaProcessorsGeoipData(BaseModel):
    geoip: MetaProcessorsGeoipDataGeoip

    ip: str


class MetaProcessorsGeoip(BaseModel):
    data: List[MetaProcessorsGeoipData]


class MetaProcessorsPhishing(BaseModel):
    data: List[str]


class MetaProcessorsRadarRankData(BaseModel):
    bucket: str

    hostname: str

    rank: Optional[float] = None


class MetaProcessorsRadarRank(BaseModel):
    data: List[MetaProcessorsRadarRankData]


class MetaProcessorsWappaDataCategory(BaseModel):
    name: str

    priority: float


class MetaProcessorsWappaDataConfidence(BaseModel):
    confidence: float

    name: str

    pattern: str

    pattern_type: str = FieldInfo(alias="patternType")


class MetaProcessorsWappaData(BaseModel):
    app: str

    categories: List[MetaProcessorsWappaDataCategory]

    confidence: List[MetaProcessorsWappaDataConfidence]

    confidence_total: float = FieldInfo(alias="confidenceTotal")

    icon: str

    website: str


class MetaProcessorsWappa(BaseModel):
    data: List[MetaProcessorsWappaData]


class MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlContentSignals(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksBotAccessControlContentSignalsEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTXTAIRules(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTxtaiRulesEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuth(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuthEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksBotAccessControl(BaseModel):
    content_signals: MetaProcessorsAgentReadinessChecksBotAccessControlContentSignals = FieldInfo(
        alias="contentSignals"
    )

    robots_txt_ai_rules: MetaProcessorsAgentReadinessChecksBotAccessControlRobotsTXTAIRules = FieldInfo(
        alias="robotsTxtAiRules"
    )

    web_bot_auth: MetaProcessorsAgentReadinessChecksBotAccessControlWebBotAuth = FieldInfo(alias="webBotAuth")


class MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksCommerceAcpEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksCommerceAcpEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksCommerceAcp(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksCommerceAcpEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksCommerceAp2Evidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksCommerceAp2EvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksCommerceAp2(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksCommerceAp2Evidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksCommerceUcpEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksCommerceUcpEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksCommerceUcp(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksCommerceUcpEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksCommerceX402EvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksCommerceX402EvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksCommerceX402EvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksCommerceX402Evidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksCommerceX402EvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksCommerceX402EvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksCommerceX402EvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksCommerceX402(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksCommerceX402Evidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksCommerce(BaseModel):
    acp: MetaProcessorsAgentReadinessChecksCommerceAcp

    ap2: MetaProcessorsAgentReadinessChecksCommerceAp2

    ucp: MetaProcessorsAgentReadinessChecksCommerceUcp

    x402: MetaProcessorsAgentReadinessChecksCommerceX402


class MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiation(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiationEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksContentAccessibility(BaseModel):
    markdown_negotiation: MetaProcessorsAgentReadinessChecksContentAccessibilityMarkdownNegotiation = FieldInfo(
        alias="markdownNegotiation"
    )


class MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeaders(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeadersEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXT(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXTEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoverabilitySitemap(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoverabilitySitemapEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoverability(BaseModel):
    link_headers: MetaProcessorsAgentReadinessChecksDiscoverabilityLinkHeaders = FieldInfo(alias="linkHeaders")

    robots_txt: MetaProcessorsAgentReadinessChecksDiscoverabilityRobotsTXT = FieldInfo(alias="robotsTxt")

    sitemap: MetaProcessorsAgentReadinessChecksDiscoverabilitySitemap


class MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCard(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCardEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryAgentSkills(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryAgentSkillsEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryAPICatalog(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryAPICatalogEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCard(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCardEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscovery(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscoveryEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResource(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResourceEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceFinding(BaseModel):
    outcome: str

    summary: str


class MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceRequest(BaseModel):
    method: str

    url: str

    headers: Optional[object] = None


class MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceResponse(BaseModel):
    status: int

    status_text: str = FieldInfo(alias="statusText")

    body_preview: Optional[str] = FieldInfo(alias="bodyPreview", default=None)

    body_size: Optional[int] = FieldInfo(alias="bodySize", default=None)

    headers: Optional[object] = None

    redirected_to: Optional[str] = FieldInfo(alias="redirectedTo", default=None)


class MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidence(BaseModel):
    action: str

    label: str

    finding: Optional[MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceFinding] = None

    request: Optional[MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceRequest] = None

    response: Optional[MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidenceResponse] = None


class MetaProcessorsAgentReadinessChecksDiscoveryWebMcp(BaseModel):
    status: str

    details: Optional[object] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    evidence: Optional[List[MetaProcessorsAgentReadinessChecksDiscoveryWebMcpEvidence]] = None

    message: Optional[str] = None


class MetaProcessorsAgentReadinessChecksDiscovery(BaseModel):
    a2a_agent_card: MetaProcessorsAgentReadinessChecksDiscoveryA2aAgentCard = FieldInfo(alias="a2aAgentCard")

    agent_skills: MetaProcessorsAgentReadinessChecksDiscoveryAgentSkills = FieldInfo(alias="agentSkills")

    api_catalog: MetaProcessorsAgentReadinessChecksDiscoveryAPICatalog = FieldInfo(alias="apiCatalog")

    mcp_server_card: MetaProcessorsAgentReadinessChecksDiscoveryMcpServerCard = FieldInfo(alias="mcpServerCard")

    oauth_discovery: MetaProcessorsAgentReadinessChecksDiscoveryOAuthDiscovery = FieldInfo(alias="oauthDiscovery")

    oauth_protected_resource: MetaProcessorsAgentReadinessChecksDiscoveryOAuthProtectedResource = FieldInfo(
        alias="oauthProtectedResource"
    )

    web_mcp: MetaProcessorsAgentReadinessChecksDiscoveryWebMcp = FieldInfo(alias="webMcp")


class MetaProcessorsAgentReadinessChecks(BaseModel):
    bot_access_control: MetaProcessorsAgentReadinessChecksBotAccessControl = FieldInfo(alias="botAccessControl")

    commerce: MetaProcessorsAgentReadinessChecksCommerce

    content_accessibility: MetaProcessorsAgentReadinessChecksContentAccessibility = FieldInfo(
        alias="contentAccessibility"
    )

    discoverability: MetaProcessorsAgentReadinessChecksDiscoverability

    discovery: MetaProcessorsAgentReadinessChecksDiscovery


class MetaProcessorsAgentReadinessNextLevelRequirement(BaseModel):
    check: str

    description: str

    prompt: str

    skill_url: str = FieldInfo(alias="skillUrl")

    spec_urls: List[str] = FieldInfo(alias="specUrls")


class MetaProcessorsAgentReadinessNextLevel(BaseModel):
    name: str

    requirements: List[MetaProcessorsAgentReadinessNextLevelRequirement]

    target: int


class MetaProcessorsAgentReadiness(BaseModel):
    checks: MetaProcessorsAgentReadinessChecks

    level: int

    level_name: str = FieldInfo(alias="levelName")

    commerce_signals: Optional[List[str]] = FieldInfo(alias="commerceSignals", default=None)

    is_commerce: Optional[bool] = FieldInfo(alias="isCommerce", default=None)

    next_level: Optional[MetaProcessorsAgentReadinessNextLevel] = FieldInfo(alias="nextLevel", default=None)


class MetaProcessorsPhishingV2(BaseModel):
    data: List[str]


class MetaProcessorsRobotsTXTDataRulesapi_emptyContentSignal(BaseModel):
    ai_input: Optional[str] = FieldInfo(alias="ai-input", default=None)

    ai_train: Optional[str] = FieldInfo(alias="ai-train", default=None)

    search: Optional[str] = None


class MetaProcessorsRobotsTXTDataRulesapi_empty(BaseModel):
    allow: List[str]

    disallow: List[str]

    content_signal: Optional[MetaProcessorsRobotsTXTDataRulesapi_emptyContentSignal] = FieldInfo(
        alias="contentSignal", default=None
    )

    crawl_delay: Optional[float] = FieldInfo(alias="crawlDelay", default=None)


class MetaProcessorsRobotsTXTDataRules(BaseModel):
    api_empty: MetaProcessorsRobotsTXTDataRulesapi_empty = FieldInfo(alias="*")


class MetaProcessorsRobotsTXTData(BaseModel):
    rules: MetaProcessorsRobotsTXTDataRules

    sitemaps: List[str]

    hash: Optional[str] = None


class MetaProcessorsRobotsTXT(BaseModel):
    data: List[MetaProcessorsRobotsTXTData]


class MetaProcessorsURLCategoriesDataContent(BaseModel):
    id: float

    name: str

    super_category_id: float


class MetaProcessorsURLCategoriesDataInheritedContent(BaseModel):
    id: float

    name: str

    super_category_id: float


class MetaProcessorsURLCategoriesDataInheritedRisk(BaseModel):
    id: float

    name: str

    super_category_id: float


class MetaProcessorsURLCategoriesDataInherited(BaseModel):
    content: List[MetaProcessorsURLCategoriesDataInheritedContent]

    from_: str = FieldInfo(alias="from")

    risks: List[MetaProcessorsURLCategoriesDataInheritedRisk]


class MetaProcessorsURLCategoriesDataRisk(BaseModel):
    id: float

    name: str

    super_category_id: float


class MetaProcessorsURLCategoriesData(BaseModel):
    content: List[MetaProcessorsURLCategoriesDataContent]

    inherited: MetaProcessorsURLCategoriesDataInherited

    name: str

    risks: List[MetaProcessorsURLCategoriesDataRisk]


class MetaProcessorsURLCategories(BaseModel):
    data: List[MetaProcessorsURLCategoriesData]


class MetaProcessors(BaseModel):
    asn: MetaProcessorsASN

    dns: MetaProcessorsDNS

    domain_categories: MetaProcessorsDomainCategories = FieldInfo(alias="domainCategories")

    geoip: MetaProcessorsGeoip

    phishing: MetaProcessorsPhishing

    radar_rank: MetaProcessorsRadarRank = FieldInfo(alias="radarRank")

    wappa: MetaProcessorsWappa

    agent_readiness: Optional[MetaProcessorsAgentReadiness] = FieldInfo(alias="agentReadiness", default=None)

    phishing_v2: Optional[MetaProcessorsPhishingV2] = None

    robots_txt: Optional[MetaProcessorsRobotsTXT] = FieldInfo(alias="robotsTxt", default=None)

    url_categories: Optional[MetaProcessorsURLCategories] = FieldInfo(alias="urlCategories", default=None)


class Meta(BaseModel):
    processors: MetaProcessors


class PageScreenshot(BaseModel):
    dhash: str

    mm3_hash: float = FieldInfo(alias="mm3Hash")

    name: str

    phash: str


class Page(BaseModel):
    apex_domain: str = FieldInfo(alias="apexDomain")

    asn: str

    asnname: str

    city: str

    country: str

    domain: str

    ip: str

    mime_type: str = FieldInfo(alias="mimeType")

    server: str

    status: str

    title: str

    tls_age_days: float = FieldInfo(alias="tlsAgeDays")

    tls_issuer: str = FieldInfo(alias="tlsIssuer")

    tls_valid_days: float = FieldInfo(alias="tlsValidDays")

    tls_valid_from: str = FieldInfo(alias="tlsValidFrom")

    url: str

    screenshot: Optional[PageScreenshot] = None


class Scanner(BaseModel):
    colo: str

    country: str


class StatsDomainStat(BaseModel):
    count: float

    countries: List[str]

    domain: str

    encoded_size: float = FieldInfo(alias="encodedSize")

    index: float

    initiators: List[str]

    ips: List[str]

    redirects: float

    size: float


class StatsIPStatASN(BaseModel):
    asn: str

    country: str

    description: str

    ip: str

    name: str

    org: str


class StatsIPStatGeoip(BaseModel):
    city: str

    country: str

    country_name: str

    ll: List[float]

    region: str


class StatsIPStat(BaseModel):
    asn: StatsIPStatASN

    countries: List[str]

    domains: List[str]

    encoded_size: float = FieldInfo(alias="encodedSize")

    geoip: StatsIPStatGeoip

    index: float

    ip: str

    ipv6: bool

    redirects: float

    requests: float

    size: float

    count: Optional[float] = None


class StatsProtocolStat(BaseModel):
    count: float

    countries: List[str]

    encoded_size: float = FieldInfo(alias="encodedSize")

    ips: List[str]

    protocol: str

    size: float


class StatsResourceStat(BaseModel):
    compression: float

    count: float

    countries: List[str]

    encoded_size: float = FieldInfo(alias="encodedSize")

    ips: List[str]

    percentage: float

    size: float

    type: str


class StatsServerStat(BaseModel):
    count: float

    countries: List[str]

    encoded_size: float = FieldInfo(alias="encodedSize")

    ips: List[str]

    server: str

    size: float


class StatsTLSStatProtocols(BaseModel):
    tls_1_3_aes_128_gcm: float = FieldInfo(alias="TLS 1.3 / AES_128_GCM")


class StatsTLSStat(BaseModel):
    count: float

    countries: List[str]

    encoded_size: float = FieldInfo(alias="encodedSize")

    ips: List[str]

    protocols: StatsTLSStatProtocols

    security_state: str = FieldInfo(alias="securityState")

    size: float


class Stats(BaseModel):
    domain_stats: List[StatsDomainStat] = FieldInfo(alias="domainStats")

    ip_stats: List[StatsIPStat] = FieldInfo(alias="ipStats")

    i_pv6_percentage: float = FieldInfo(alias="IPv6Percentage")

    malicious: float

    protocol_stats: List[StatsProtocolStat] = FieldInfo(alias="protocolStats")

    resource_stats: List[StatsResourceStat] = FieldInfo(alias="resourceStats")

    secure_percentage: float = FieldInfo(alias="securePercentage")

    secure_requests: float = FieldInfo(alias="secureRequests")

    server_stats: List[StatsServerStat] = FieldInfo(alias="serverStats")

    tls_stats: List[StatsTLSStat] = FieldInfo(alias="tlsStats")

    total_links: float = FieldInfo(alias="totalLinks")

    uniq_asns: float = FieldInfo(alias="uniqASNs")

    uniq_countries: float = FieldInfo(alias="uniqCountries")


class TaskOptions(BaseModel):
    custom_headers: Optional[object] = FieldInfo(alias="customHeaders", default=None)
    """Custom headers set."""

    screenshots_resolutions: Optional[List[str]] = FieldInfo(alias="screenshotsResolutions", default=None)


class Task(BaseModel):
    apex_domain: str = FieldInfo(alias="apexDomain")

    domain: str

    dom_url: str = FieldInfo(alias="domURL")

    method: str

    options: TaskOptions

    report_url: str = FieldInfo(alias="reportURL")

    screenshot_url: str = FieldInfo(alias="screenshotURL")

    source: str

    success: bool

    time: str

    url: str

    uuid: str

    visibility: str


class VerdictsOverall(BaseModel):
    categories: List[str]

    has_verdicts: bool = FieldInfo(alias="hasVerdicts")

    malicious: bool

    tags: List[str]


class Verdicts(BaseModel):
    overall: VerdictsOverall


class ScanGetResponse(BaseModel):
    data: Data

    lists: Lists

    meta: Meta

    page: Page

    scanner: Scanner

    stats: Stats

    task: Task

    verdicts: Verdicts



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["ClientCertificateInputParam"]


class ClientCertificateInputParam(TypedDict, total=False):
    certificate_id: Required[str]
    """UUID of Cloudflare managed certificate."""

    cn: Required[str]
    """Common Name that is protected by the certificate."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)
from .labels import (
    LabelsResource,
    AsyncLabelsResource,
    LabelsResourceWithRawResponse,
    AsyncLabelsResourceWithRawResponse,
    LabelsResourceWithStreamingResponse,
    AsyncLabelsResourceWithStreamingResponse,
)
from .managed import (
    ManagedResource,
    AsyncManagedResource,
    ManagedResourceWithRawResponse,
    AsyncManagedResourceWithRawResponse,
    ManagedResourceWithStreamingResponse,
    AsyncManagedResourceWithStreamingResponse,
)

__all__ = [
    "UserResource",
    "AsyncUserResource",
    "UserResourceWithRawResponse",
    "AsyncUserResourceWithRawResponse",
    "UserResourceWithStreamingResponse",
    "AsyncUserResourceWithStreamingResponse",
    "ManagedResource",
    "AsyncManagedResource",
    "ManagedResourceWithRawResponse",
    "AsyncManagedResourceWithRawResponse",
    "ManagedResourceWithStreamingResponse",
    "AsyncManagedResourceWithStreamingResponse",
    "LabelsResource",
    "AsyncLabelsResource",
    "LabelsResourceWithRawResponse",
    "AsyncLabelsResourceWithRawResponse",
    "LabelsResourceWithStreamingResponse",
    "AsyncLabelsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["PrebuiltPolicyListResponse"]


class PrebuiltPolicyListResponse(BaseModel):
    applicable_destinations: List[Literal["NONE", "ZERO_TRUST_LIST"]]

    policy_description: str

    policy_name: str

    policy_string: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["DatasetDownloadParams"]


class DatasetDownloadParams(TypedDict, total=False):
    dataset_id: Required[Annotated[int, PropertyInfo(alias="datasetId")]]

    format: Literal["JSON", "CSV"]
    """Format in which results will be returned."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .certificates import (
    CertificatesResource,
    AsyncCertificatesResource,
    CertificatesResourceWithRawResponse,
    AsyncCertificatesResourceWithRawResponse,
    CertificatesResourceWithStreamingResponse,
    AsyncCertificatesResourceWithStreamingResponse,
)
from .certificate_pack import (
    CertificatePackResource,
    AsyncCertificatePackResource,
    CertificatePackResourceWithRawResponse,
    AsyncCertificatePackResourceWithRawResponse,
    CertificatePackResourceWithStreamingResponse,
    AsyncCertificatePackResourceWithStreamingResponse,
)

__all__ = [
    "CertificatesResource",
    "AsyncCertificatesResource",
    "CertificatesResourceWithRawResponse",
    "AsyncCertificatesResourceWithRawResponse",
    "CertificatesResourceWithStreamingResponse",
    "AsyncCertificatesResourceWithStreamingResponse",
    "CertificatePackResource",
    "AsyncCertificatePackResource",
    "CertificatePackResourceWithRawResponse",
    "AsyncCertificatePackResourceWithRawResponse",
    "CertificatePackResourceWithStreamingResponse",
    "AsyncCertificatePackResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["RuleUpdateParams"]


class RuleUpdateParams(TypedDict, total=False):
    account_id: Required[str]

    automatic_advertisement: Required[Optional[bool]]
    """
    Toggle on if you would like Cloudflare to automatically advertise the IP
    Prefixes within the rule via Magic Transit when the rule is triggered. Only
    available for users of Magic Transit.
    """

    name: Required[str]
    """The name of the rule.

    Must be unique. Supports characters A-Z, a-z, 0-9, underscore (\\__), dash (-),
    period (.), and tilde (~). You can’t have a space in the rule name. Max 256
    characters.
    """

    prefixes: Required[SequenceNotStr[str]]

    type: Required[Literal["threshold", "zscore", "advanced_ddos"]]
    """MNM rule type."""

    bandwidth_threshold: float
    """The number of bits per second for the rule.

    When this value is exceeded for the set duration, an alert notification is sent.
    Minimum of 1 and no maximum.
    """

    duration: Literal["1m", "5m", "10m", "15m", "20m", "30m", "45m", "60m"]
    """
    The amount of time that the rule threshold must be exceeded to send an alert
    notification. The final value must be equivalent to one of the following 8
    values ["1m","5m","10m","15m","20m","30m","45m","60m"].
    """

    packet_threshold: float
    """The number of packets per second for the rule.

    When this value is exceeded for the set duration, an alert notification is sent.
    Minimum of 1 and no maximum.
    """

    prefix_match: Optional[Literal["exact", "subnet", "supernet"]]
    """
    Prefix match type to be applied for a prefix auto advertisement when using an
    advanced_ddos rule.
    """

    zscore_sensitivity: Optional[Literal["low", "medium", "high"]]
    """Level of sensitivity set for zscore rules."""

    zscore_target: Optional[Literal["bits", "packets"]]
    """Target of the zscore rule analysis."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from .items import (
    ItemsResource,
    AsyncItemsResource,
    ItemsResourceWithRawResponse,
    AsyncItemsResourceWithRawResponse,
    ItemsResourceWithStreamingResponse,
    AsyncItemsResourceWithStreamingResponse,
)
from ......_types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ......_utils import path_template, maybe_transform, async_maybe_transform
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_wrappers import ResultWrapper
from ......pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ......_base_client import AsyncPaginator, make_request_options
from ......types.ddos_protection.advanced_tcp_protection.tcp_flow_protection import rule_list_params, rule_create_params
from ......types.ddos_protection.advanced_tcp_protection.tcp_flow_protection.rule_list_response import RuleListResponse
from ......types.ddos_protection.advanced_tcp_protection.tcp_flow_protection.rule_create_response import (
    RuleCreateResponse,
)
from ......types.ddos_protection.advanced_tcp_protection.tcp_flow_protection.rule_bulk_delete_response import (
    RuleBulkDeleteResponse,
)

__all__ = ["RulesResource", "AsyncRulesResource"]


class RulesResource(SyncAPIResource):
    @cached_property
    def items(self) -> ItemsResource:
        return ItemsResource(self._client)

    @cached_property
    def with_raw_response(self) -> RulesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return RulesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RulesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return RulesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        burst_sensitivity: str,
        mode: str,
        name: str,
        rate_sensitivity: str,
        scope: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RuleCreateResponse]:
        """
        Create a TCP Flow Protection rule for an account.

        Args:
          account_id: Identifier.

          burst_sensitivity: The burst sensitivity. Must be one of 'low', 'medium', 'high'.

          mode: The mode for the TCP Flow Protection. Must be one of 'enabled', 'disabled',
              'monitoring'.

          name: The name of the TCP Flow Protection rule. Value is relative to the 'scope'
              setting. For 'global' scope, name should be 'global'. For either the 'region' or
              'datacenter' scope, name should be the actual name of the region or datacenter,
              e.g., 'wnam' or 'lax'.

          rate_sensitivity: The rate sensitivity. Must be one of 'low', 'medium', 'high'.

          scope: The scope for the TCP Flow Protection rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/magic/advanced_tcp_protection/configs/tcp_flow_protection/rules",
                account_id=account_id,
            ),
            body=maybe_transform(
                {
                    "burst_sensitivity": burst_sensitivity,
                    "mode": mode,
                    "name": name,
                    "rate_sensitivity": rate_sensitivity,
                    "scope": scope,
                },
                rule_create_params.RuleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RuleCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RuleCreateResponse]], ResultWrapper[RuleCreateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        direction: str | Omit = omit,
        order: str | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[RuleListResponse]:
        """
        List all TCP Flow Protection rules for an account.

        Args:
          account_id: Identifier.

          direction: The direction of ordering (ASC or DESC). Defaults to 'ASC'.

          order: The field to order by. Defaults to 'prefix'.

          page: The page number for pagination. Defaults to 1.

          per_page: The number of items per page. Must be between 10 and 1000. Defaults to 25.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template(
                "/accounts/{account_id}/magic/advanced_tcp_protection/configs/tcp_flow_protection/rules",
                account_id=account_id,
            ),
            page=SyncV4PagePaginationArray[RuleListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "direction": direction,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                    },
                    rule_list_params.RuleListParams,
                ),
            ),
            model=RuleListResponse,
        )

    def bulk_delete(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RuleBulkDeleteResponse:
        """
        Delete all TCP Flow Protection rules for an account.

        Args:
          account_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/magic/advanced_tcp_protection/configs/tcp_flow_protection/rules",
                account_id=account_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RuleBulkDeleteResponse,
        )


class AsyncRulesResource(AsyncAPIResource):
    @cached_property
    def items(self) -> AsyncItemsResource:
        return AsyncItemsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncRulesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRulesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRulesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncRulesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        burst_sensitivity: str,
        mode: str,
        name: str,
        rate_sensitivity: str,
        scope: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RuleCreateResponse]:
        """
        Create a TCP Flow Protection rule for an account.

        Args:
          account_id: Identifier.

          burst_sensitivity: The burst sensitivity. Must be one of 'low', 'medium', 'high'.

          mode: The mode for the TCP Flow Protection. Must be one of 'enabled', 'disabled',
              'monitoring'.

          name: The name of the TCP Flow Protection rule. Value is relative to the 'scope'
              setting. For 'global' scope, name should be 'global'. For either the 'region' or
              'datacenter' scope, name should be the actual name of the region or datacenter,
              e.g., 'wnam' or 'lax'.

          rate_sensitivity: The rate sensitivity. Must be one of 'low', 'medium', 'high'.

          scope: The scope for the TCP Flow Protection rule.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/magic/advanced_tcp_protection/configs/tcp_flow_protection/rules",
                account_id=account_id,
            ),
            body=await async_maybe_transform(
                {
                    "burst_sensitivity": burst_sensitivity,
                    "mode": mode,
                    "name": name,
                    "rate_sensitivity": rate_sensitivity,
                    "scope": scope,
                },
                rule_create_params.RuleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RuleCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RuleCreateResponse]], ResultWrapper[RuleCreateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        direction: str | Omit = omit,
        order: str | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[RuleListResponse, AsyncV4PagePaginationArray[RuleListResponse]]:
        """
        List all TCP Flow Protection rules for an account.

        Args:
          account_id: Identifier.

          direction: The direction of ordering (ASC or DESC). Defaults to 'ASC'.

          order: The field to order by. Defaults to 'prefix'.

          page: The page number for pagination. Defaults to 1.

          per_page: The number of items per page. Must be between 10 and 1000. Defaults to 25.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template(
                "/accounts/{account_id}/magic/advanced_tcp_protection/configs/tcp_flow_protection/rules",
                account_id=account_id,
            ),
            page=AsyncV4PagePaginationArray[RuleListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "direction": direction,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                    },
                    rule_list_params.RuleListParams,
                ),
            ),
            model=RuleListResponse,
        )

    async def bulk_delete(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RuleBulkDeleteResponse:
        """
        Delete all TCP Flow Protection rules for an account.

        Args:
          account_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/magic/advanced_tcp_protection/configs/tcp_flow_protection/rules",
                account_id=account_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RuleBulkDeleteResponse,
        )


class RulesResourceWithRawResponse:
    def __init__(self, rules: RulesResource) -> None:
        self._rules = rules

        self.create = to_raw_response_wrapper(
            rules.create,
        )
        self.list = to_raw_response_wrapper(
            rules.list,
        )
        self.bulk_delete = to_raw_response_wrapper(
            rules.bulk_delete,
        )

    @cached_property
    def items(self) -> ItemsResourceWithRawResponse:
        return ItemsResourceWithRawResponse(self._rules.items)


class AsyncRulesResourceWithRawResponse:
    def __init__(self, rules: AsyncRulesResource) -> None:
        self._rules = rules

        self.create = async_to_raw_response_wrapper(
            rules.create,
        )
        self.list = async_to_raw_response_wrapper(
            rules.list,
        )
        self.bulk_delete = async_to_raw_response_wrapper(
            rules.bulk_delete,
        )

    @cached_property
    def items(self) -> AsyncItemsResourceWithRawResponse:
        return AsyncItemsResourceWithRawResponse(self._rules.items)


class RulesResourceWithStreamingResponse:
    def __init__(self, rules: RulesResource) -> None:
        self._rules = rules

        self.create = to_streamed_response_wrapper(
            rules.create,
        )
        self.list = to_streamed_response_wrapper(
            rules.list,
        )
        self.bulk_delete = to_streamed_response_wrapper(
            rules.bulk_delete,
        )

    @cached_property
    def items(self) -> ItemsResourceWithStreamingResponse:
        return ItemsResourceWithStreamingResponse(self._rules.items)


class AsyncRulesResourceWithStreamingResponse:
    def __init__(self, rules: AsyncRulesResource) -> None:
        self._rules = rules

        self.create = async_to_streamed_response_wrapper(
            rules.create,
        )
        self.list = async_to_streamed_response_wrapper(
            rules.list,
        )
        self.bulk_delete = async_to_streamed_response_wrapper(
            rules.bulk_delete,
        )

    @cached_property
    def items(self) -> AsyncItemsResourceWithStreamingResponse:
        return AsyncItemsResourceWithStreamingResponse(self._rules.items)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import datetime
from typing import Union
from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["DatasetListParams"]


class DatasetListParams(TypedDict, total=False):
    dataset_type: Annotated[Literal["RANKING_BUCKET", "REPORT"], PropertyInfo(alias="datasetType")]
    """Filters results by dataset type."""

    date: Annotated[Union[str, datetime.date], PropertyInfo(format="iso8601")]
    """Filters results by the specified date."""

    format: Literal["JSON", "CSV"]
    """Format in which results will be returned."""

    limit: int
    """Limits the number of objects returned in the response."""

    offset: int
    """Skips the specified number of objects before fetching the results."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["IncomingCreateParams"]


class IncomingCreateParams(TypedDict, total=False):
    zone_id: Required[str]

    auto_refresh_seconds: Required[float]
    """
    How often should a secondary zone auto refresh regardless of DNS NOTIFY. Not
    applicable for primary zones.
    """

    name: Required[str]
    """Zone name."""

    peers: Required[SequenceNotStr[str]]
    """A list of peer tags."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["LogDeleteParams", "Filter"]


class LogDeleteParams(TypedDict, total=False):
    account_id: Required[str]

    filters: Iterable[Filter]

    limit: int

    order_by: Literal[
        "created_at",
        "provider",
        "model",
        "model_type",
        "success",
        "cached",
        "cost",
        "tokens_in",
        "tokens_out",
        "duration",
        "feedback",
    ]

    order_by_direction: Literal["asc", "desc"]


class Filter(TypedDict, total=False):
    key: Required[
        Literal[
            "id",
            "created_at",
            "request_content_type",
            "response_content_type",
            "request_type",
            "success",
            "cached",
            "provider",
            "model",
            "model_type",
            "cost",
            "tokens",
            "tokens_in",
            "tokens_out",
            "duration",
            "feedback",
            "event_id",
            "metadata.key",
            "metadata.value",
            "authentication",
            "wholesale",
            "compatibilityMode",
            "dlp_action",
        ]
    ]

    operator: Required[Literal["eq", "neq", "contains", "lt", "gt"]]

    value: Required[SequenceNotStr[Union[Optional[str], float, bool]]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = [
    "ScrapeCreateParams",
    "Variant0",
    "Variant0Element",
    "Variant0AddScriptTag",
    "Variant0AddStyleTag",
    "Variant0Authenticate",
    "Variant0Cookie",
    "Variant0GotoOptions",
    "Variant0Viewport",
    "Variant0WaitForSelector",
    "Variant1",
    "Variant1Element",
    "Variant1AddScriptTag",
    "Variant1AddStyleTag",
    "Variant1Authenticate",
    "Variant1Cookie",
    "Variant1GotoOptions",
    "Variant1Viewport",
    "Variant1WaitForSelector",
]


class Variant0(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    elements: Required[Iterable[Variant0Element]]

    html: Required[str]
    """Set the content of the page, eg: `<h1>Hello World!!</h1>`.

    Either `html` or `url` must be set.
    """

    cache_ttl: Annotated[float, PropertyInfo(alias="cacheTTL")]
    """Cache TTL default is 5s. Set to 0 to disable."""

    action_timeout: Annotated[float, PropertyInfo(alias="actionTimeout")]
    """
    The maximum duration allowed for the browser action to complete after the page
    has loaded (such as taking screenshots, extracting content, or generating PDFs).
    If this time limit is exceeded, the action stops and returns a timeout error.
    """

    add_script_tag: Annotated[Iterable[Variant0AddScriptTag], PropertyInfo(alias="addScriptTag")]
    """Adds a `<script>` tag into the page with the desired URL or content."""

    add_style_tag: Annotated[Iterable[Variant0AddStyleTag], PropertyInfo(alias="addStyleTag")]
    """
    Adds a `<link rel="stylesheet">` tag into the page with the desired URL or a
    `<style type="text/css">` tag with the content.
    """

    allow_request_pattern: Annotated[SequenceNotStr[str], PropertyInfo(alias="allowRequestPattern")]
    """Only allow requests that match the provided regex patterns, eg. '/^.\\**\\..(css)'."""

    allow_resource_types: Annotated[
        List[
            Literal[
                "document",
                "stylesheet",
                "image",
                "media",
                "font",
                "script",
                "texttrack",
                "xhr",
                "fetch",
                "prefetch",
                "eventsource",
                "websocket",
                "manifest",
                "signedexchange",
                "ping",
                "cspviolationreport",
                "preflight",
                "other",
            ]
        ],
        PropertyInfo(alias="allowResourceTypes"),
    ]
    """Only allow requests that match the provided resource types, eg.

    'image' or 'script'.
    """

    authenticate: Variant0Authenticate
    """Provide credentials for HTTP authentication."""

    best_attempt: Annotated[bool, PropertyInfo(alias="bestAttempt")]
    """Attempt to proceed when 'awaited' events fail or timeout."""

    cookies: Iterable[Variant0Cookie]
    """Check [options](https://pptr.dev/api/puppeteer.page.setcookie)."""

    emulate_media_type: Annotated[str, PropertyInfo(alias="emulateMediaType")]

    goto_options: Annotated[Variant0GotoOptions, PropertyInfo(alias="gotoOptions")]
    """Check [options](https://pptr.dev/api/puppeteer.gotooptions)."""

    reject_request_pattern: Annotated[SequenceNotStr[str], PropertyInfo(alias="rejectRequestPattern")]
    """Block undesired requests that match the provided regex patterns, eg.

    '/^.\\**\\..(css)'.
    """

    reject_resource_types: Annotated[
        List[
            Literal[
                "document",
                "stylesheet",
                "image",
                "media",
                "font",
                "script",
                "texttrack",
                "xhr",
                "fetch",
                "prefetch",
                "eventsource",
                "websocket",
                "manifest",
                "signedexchange",
                "ping",
                "cspviolationreport",
                "preflight",
                "other",
            ]
        ],
        PropertyInfo(alias="rejectResourceTypes"),
    ]
    """Block undesired requests that match the provided resource types, eg.

    'image' or 'script'.
    """

    set_extra_http_headers: Annotated[Dict[str, str], PropertyInfo(alias="setExtraHTTPHeaders")]

    set_java_script_enabled: Annotated[bool, PropertyInfo(alias="setJavaScriptEnabled")]

    user_agent: Annotated[str, PropertyInfo(alias="userAgent")]

    viewport: Variant0Viewport
    """Check [options](https://pptr.dev/api/puppeteer.page.setviewport)."""

    wait_for_selector: Annotated[Variant0WaitForSelector, PropertyInfo(alias="waitForSelector")]
    """Wait for the selector to appear in page.

    Check [options](https://pptr.dev/api/puppeteer.page.waitforselector).
    """

    wait_for_timeout: Annotated[float, PropertyInfo(alias="waitForTimeout")]
    """Waits for a specified timeout before continuing."""


class Variant0Element(TypedDict, total=False):
    selector: Required[str]


class Variant0AddScriptTag(TypedDict, total=False):
    id: str

    content: str

    type: str

    url: str


class Variant0AddStyleTag(TypedDict, total=False):
    content: str

    url: str


class Variant0Authenticate(TypedDict, total=False):
    """Provide credentials for HTTP authentication."""

    password: Required[str]

    username: Required[str]


class Variant0Cookie(TypedDict, total=False):
    name: Required[str]
    """Cookie name."""

    value: Required[str]

    domain: str

    expires: float

    http_only: Annotated[bool, PropertyInfo(alias="httpOnly")]

    partition_key: Annotated[str, PropertyInfo(alias="partitionKey")]

    path: str

    priority: Literal["Low", "Medium", "High"]

    same_party: Annotated[bool, PropertyInfo(alias="sameParty")]

    same_site: Annotated[Literal["Strict", "Lax", "None"], PropertyInfo(alias="sameSite")]

    secure: bool

    source_port: Annotated[float, PropertyInfo(alias="sourcePort")]

    source_scheme: Annotated[Literal["Unset", "NonSecure", "Secure"], PropertyInfo(alias="sourceScheme")]

    url: str


class Variant0GotoOptions(TypedDict, total=False):
    """Check [options](https://pptr.dev/api/puppeteer.gotooptions)."""

    referer: str

    referrer_policy: Annotated[str, PropertyInfo(alias="referrerPolicy")]

    timeout: float

    wait_until: Annotated[
        Union[
            Literal["load", "domcontentloaded", "networkidle0", "networkidle2"],
            List[Literal["load", "domcontentloaded", "networkidle0", "networkidle2"]],
        ],
        PropertyInfo(alias="waitUntil"),
    ]


class Variant0Viewport(TypedDict, total=False):
    """Check [options](https://pptr.dev/api/puppeteer.page.setviewport)."""

    height: Required[float]

    width: Required[float]

    device_scale_factor: Annotated[float, PropertyInfo(alias="deviceScaleFactor")]

    has_touch: Annotated[bool, PropertyInfo(alias="hasTouch")]

    is_landscape: Annotated[bool, PropertyInfo(alias="isLandscape")]

    is_mobile: Annotated[bool, PropertyInfo(alias="isMobile")]


class Variant0WaitForSelector(TypedDict, total=False):
    """Wait for the selector to appear in page.

    Check [options](https://pptr.dev/api/puppeteer.page.waitforselector).
    """

    selector: Required[str]

    hidden: Literal[True]

    timeout: float

    visible: Literal[True]


class Variant1(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    elements: Required[Iterable[Variant1Element]]

    url: Required[str]
    """URL to navigate to, eg. `https://example.com`."""

    cache_ttl: Annotated[float, PropertyInfo(alias="cacheTTL")]
    """Cache TTL default is 5s. Set to 0 to disable."""

    action_timeout: Annotated[float, PropertyInfo(alias="actionTimeout")]
    """
    The maximum duration allowed for the browser action to complete after the page
    has loaded (such as taking screenshots, extracting content, or generating PDFs).
    If this time limit is exceeded, the action stops and returns a timeout error.
    """

    add_script_tag: Annotated[Iterable[Variant1AddScriptTag], PropertyInfo(alias="addScriptTag")]
    """Adds a `<script>` tag into the page with the desired URL or content."""

    add_style_tag: Annotated[Iterable[Variant1AddStyleTag], PropertyInfo(alias="addStyleTag")]
    """
    Adds a `<link rel="stylesheet">` tag into the page with the desired URL or a
    `<style type="text/css">` tag with the content.
    """

    allow_request_pattern: Annotated[SequenceNotStr[str], PropertyInfo(alias="allowRequestPattern")]
    """Only allow requests that match the provided regex patterns, eg. '/^.\\**\\..(css)'."""

    allow_resource_types: Annotated[
        List[
            Literal[
                "document",
                "stylesheet",
                "image",
                "media",
                "font",
                "script",
                "texttrack",
                "xhr",
                "fetch",
                "prefetch",
                "eventsource",
                "websocket",
                "manifest",
                "signedexchange",
                "ping",
                "cspviolationreport",
                "preflight",
                "other",
            ]
        ],
        PropertyInfo(alias="allowResourceTypes"),
    ]
    """Only allow requests that match the provided resource types, eg.

    'image' or 'script'.
    """

    authenticate: Variant1Authenticate
    """Provide credentials for HTTP authentication."""

    best_attempt: Annotated[bool, PropertyInfo(alias="bestAttempt")]
    """Attempt to proceed when 'awaited' events fail or timeout."""

    cookies: Iterable[Variant1Cookie]
    """Check [options](https://pptr.dev/api/puppeteer.page.setcookie)."""

    emulate_media_type: Annotated[str, PropertyInfo(alias="emulateMediaType")]

    goto_options: Annotated[Variant1GotoOptions, PropertyInfo(alias="gotoOptions")]
    """Check [options](https://pptr.dev/api/puppeteer.gotooptions)."""

    reject_request_pattern: Annotated[SequenceNotStr[str], PropertyInfo(alias="rejectRequestPattern")]
    """Block undesired requests that match the provided regex patterns, eg.

    '/^.\\**\\..(css)'.
    """

    reject_resource_types: Annotated[
        List[
            Literal[
                "document",
                "stylesheet",
                "image",
                "media",
                "font",
                "script",
                "texttrack",
                "xhr",
                "fetch",
                "prefetch",
                "eventsource",
                "websocket",
                "manifest",
                "signedexchange",
                "ping",
                "cspviolationreport",
                "preflight",
                "other",
            ]
        ],
        PropertyInfo(alias="rejectResourceTypes"),
    ]
    """Block undesired requests that match the provided resource types, eg.

    'image' or 'script'.
    """

    set_extra_http_headers: Annotated[Dict[str, str], PropertyInfo(alias="setExtraHTTPHeaders")]

    set_java_script_enabled: Annotated[bool, PropertyInfo(alias="setJavaScriptEnabled")]

    user_agent: Annotated[str, PropertyInfo(alias="userAgent")]

    viewport: Variant1Viewport
    """Check [options](https://pptr.dev/api/puppeteer.page.setviewport)."""

    wait_for_selector: Annotated[Variant1WaitForSelector, PropertyInfo(alias="waitForSelector")]
    """Wait for the selector to appear in page.

    Check [options](https://pptr.dev/api/puppeteer.page.waitforselector).
    """

    wait_for_timeout: Annotated[float, PropertyInfo(alias="waitForTimeout")]
    """Waits for a specified timeout before continuing."""


class Variant1Element(TypedDict, total=False):
    selector: Required[str]


class Variant1AddScriptTag(TypedDict, total=False):
    id: str

    content: str

    type: str

    url: str


class Variant1AddStyleTag(TypedDict, total=False):
    content: str

    url: str


class Variant1Authenticate(TypedDict, total=False):
    """Provide credentials for HTTP authentication."""

    password: Required[str]

    username: Required[str]


class Variant1Cookie(TypedDict, total=False):
    name: Required[str]
    """Cookie name."""

    value: Required[str]

    domain: str

    expires: float

    http_only: Annotated[bool, PropertyInfo(alias="httpOnly")]

    partition_key: Annotated[str, PropertyInfo(alias="partitionKey")]

    path: str

    priority: Literal["Low", "Medium", "High"]

    same_party: Annotated[bool, PropertyInfo(alias="sameParty")]

    same_site: Annotated[Literal["Strict", "Lax", "None"], PropertyInfo(alias="sameSite")]

    secure: bool

    source_port: Annotated[float, PropertyInfo(alias="sourcePort")]

    source_scheme: Annotated[Literal["Unset", "NonSecure", "Secure"], PropertyInfo(alias="sourceScheme")]

    url: str


class Variant1GotoOptions(TypedDict, total=False):
    """Check [options](https://pptr.dev/api/puppeteer.gotooptions)."""

    referer: str

    referrer_policy: Annotated[str, PropertyInfo(alias="referrerPolicy")]

    timeout: float

    wait_until: Annotated[
        Union[
            Literal["load", "domcontentloaded", "networkidle0", "networkidle2"],
            List[Literal["load", "domcontentloaded", "networkidle0", "networkidle2"]],
        ],
        PropertyInfo(alias="waitUntil"),
    ]


class Variant1Viewport(TypedDict, total=False):
    """Check [options](https://pptr.dev/api/puppeteer.page.setviewport)."""

    height: Required[float]

    width: Required[float]

    device_scale_factor: Annotated[float, PropertyInfo(alias="deviceScaleFactor")]

    has_touch: Annotated[bool, PropertyInfo(alias="hasTouch")]

    is_landscape: Annotated[bool, PropertyInfo(alias="isLandscape")]

    is_mobile: Annotated[bool, PropertyInfo(alias="isMobile")]


class Variant1WaitForSelector(TypedDict, total=False):
    """Wait for the selector to appear in page.

    Check [options](https://pptr.dev/api/puppeteer.page.waitforselector).
    """

    selector: Required[str]

    hidden: Literal[True]

    timeout: float

    visible: Literal[True]


ScrapeCreateParams: TypeAlias = Union[Variant0, Variant1]
